@@ -22,9 +22,9 @@ This example may be removed or be dramatically refactored in the near future.
 """
 import random
 
-from echonest import video, audio
-from echonest.sorting import *
-from echonest.selection import *
+from echonest.remix import video, audio
+from echonest.remix.sorting import *
+from echonest.remix.selection import *
 
 usage = """
 Usage:
